Circe Web UI

# Circe

Circe est une API web destinée à la conversion de documents (exemple: convertir du HTML en PDF). Pour plus de renseignements, veuillez vous référer au dépôt Gitlab. A titre de démonstration, Vous pouvez également utiliser l'interface ci-dessous:

## Étape n°1: Dépôt de vos fichiers

Glissez dans ce cadre les fichiers que vous souhaitez convertir (ou cliquez dessus pour ouvrir une boite de dialogue):

## Étape n°2: Choix des conversions

Choisissez ici vos conversions et leurs options. Les conversions sont faites dans l'ordre dans lequel vous les ajoutez. Vous pouvez aussi les réordonner.

## Étape n°3: Confirmation

Le traitement est terminé, vous pouvez récuperer vos fichiers:

Cliquez ici pour un autre travail.